.. image:: https://github.com/turcar/turcar/blob/master/turcar/res/Ukraine.png

`Support Ukraine! <https://github.com/turcar/turcar/wiki/Support-Ukraine>`_

======
turcar
======

turcar is a Python `IDE <https://en.wikipedia.org/wiki/Integrated_development_environment>`_ meant for learning programming.


End users
---------
See https://turcar.org and `wiki <https://github.com/turcar/turcar/wiki>`_ for more info.


Contributors
------------
Contributions are welcome! See `CONTRIBUTING.rst <https://github.com/turcar/turcar/blob/master/CONTRIBUTING.rst>`_ for more info.


Sponsors
----------
You can sponsor development of turcar by sending a donation to turcar's main author Aivar Annamaa: https://github.com/turcar/turcar/wiki/Sponsors
